"""
**Data tools**.

Embedded data: "ele_table.csv", "ele_megnet.json", "ie.json", "oe.csv"
"""

__all__ = ["namesplit", "mp_access", "check_data", "data_sep"]
